==> apache-hop-2.13.0-src.tar.gz: apache-hop-2.13.0/plugins/transforms/ifnull/src/test/java/org/apache/hop/pipeline/transforms/ifnull/IfNullMetaInjectionTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hop.pipeline.transforms.ifnull;

import org.apache.hop.core.injection.BaseMetadataInjectionTest;
import org.apache.hop.junit.rules.RestoreHopEngineEnvironment;
import org.junit.Before;
import org.junit.ClassRule;
import org.junit.Test;

public class IfNullMetaInjectionTest extends BaseMetadataInjectionTest<IfNullMeta> {
  @ClassRule public static RestoreHopEngineEnvironment env = new RestoreHopEngineEnvironment();

  @Before
  public void setup() throws Exception {
    setup(new IfNullMeta());
  }

  @Test
  public void test() throws Exception {
    check("FIELD_NAME", () -> meta.getFields().get(0).getName());
    check("REPLACE_VALUE", () -> meta.getFields().get(0).getValue());
    check("REPLACE_MASK", () -> meta.getFields().get(0).getMask());
    check("SET_EMPTY_STRING", () -> meta.getFields().get(0).isSetEmptyString());

    check("TYPE_NAME", () -> meta.getValueTypes().get(0).getName());
    check("TYPE_REPLACE_VALUE", () -> meta.getValueTypes().get(0).getValue());
    check("TYPE_REPLACE_MASK", () -> meta.getValueTypes().get(0).getMask());
    check("SET_TYPE_EMPTY_STRING", () -> meta.getValueTypes().get(0).isSetEmptyString());

    check("SELECT_FIELDS", () -> meta.isSelectFields());
    check("SELECT_VALUES_TYPE", () -> meta.isSelectValuesType());
    check("REPLACE_ALL_BY_VALUE", () -> meta.getReplaceAllByValue());
    check("REPLACE_ALL_MASK", () -> meta.getReplaceAllMask());
    check("SET_EMPTY_STRING_ALL", () -> meta.isSetEmptyStringAll());
  }
}

==> apache-hop-2.16.0-src.tar.gz: apache-hop-2.16.0/plugins/transforms/ifnull/src/test/java/org/apache/hop/pipeline/transforms/ifnull/IfNullMetaInjectionTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hop.pipeline.transforms.ifnull;

import org.apache.hop.core.injection.BaseMetadataInjectionTestJunit5;
import org.apache.hop.junit.rules.RestoreHopEngineEnvironmentExtension;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.RegisterExtension;

class IfNullMetaInjectionTest extends BaseMetadataInjectionTestJunit5<IfNullMeta> {
  @RegisterExtension
  static RestoreHopEngineEnvironmentExtension env = new RestoreHopEngineEnvironmentExtension();

  @BeforeEach
  void setup() throws Exception {
    setup(new IfNullMeta());
  }

  @Test
  void test() throws Exception {
    check("FIELD_NAME", () -> meta.getFields().get(0).getName());
    check("REPLACE_VALUE", () -> meta.getFields().get(0).getValue());
    check("REPLACE_MASK", () -> meta.getFields().get(0).getMask());
    check("SET_EMPTY_STRING", () -> meta.getFields().get(0).isSetEmptyString());

    check("TYPE_NAME", () -> meta.getValueTypes().get(0).getName());
    check("TYPE_REPLACE_VALUE", () -> meta.getValueTypes().get(0).getValue());
    check("TYPE_REPLACE_MASK", () -> meta.getValueTypes().get(0).getMask());
    check("SET_TYPE_EMPTY_STRING", () -> meta.getValueTypes().get(0).isSetEmptyString());

    check("SELECT_FIELDS", () -> meta.isSelectFields());
    check("SELECT_VALUES_TYPE", () -> meta.isSelectValuesType());
    check("REPLACE_ALL_BY_VALUE", () -> meta.getReplaceAllByValue());
    check("REPLACE_ALL_MASK", () -> meta.getReplaceAllMask());
    check("SET_EMPTY_STRING_ALL", () -> meta.isSetEmptyStringAll());
  }
}
